<!--
 * @Descripttion: Say something
 * @version: 0.1
 * @Author: ziyang-W, ziyangw@yeah.net
 * @Co.: IMICAMS
 * @Date: 2022-06-20 01:36:45
 * @LastEditTime: 2022-06-27 11:18:41
 * Copyright (c) 2022 by ziyang-W (ziyangw@yeah.net), All Rights Reserved. 
-->
# 介绍

整个代码库主要存放本人在硕士期间编写的多种函数，目前仅主要包括以下几个方面：

1. 数据预处理
2. 统计学检验
3. 机器学习
4. 深度学习
5. 绘图
6. 办公自动化

其中，`dataPrep.py`是最常用到的一个模块，其中的`make_logInfo`函数会根据传入的数据路径和文件名，以及当前日期和时间，创建日志模块，方便保存后续数据分析和处理的结果。`make_logInfo`的返回结果`logInfo`会作为其他函数的参数传入，用于判断是否保存相关的数据。

代码会及时进行更新和完善，并且每个函数都附带了详细的注释。

# TODO：
- [ ] 介绍各个模块内函数的作用和调用逻辑
- [ ] 完善深度学习的模块
- [ ] 完善机器学习模型调优的模块代码
- [ ] 完善机器学习模型的交叉验证模块
- [ ] 补充模块之间的摘要图


# REFERENCE
